@@ -14,7 +14,7 @@ Usage::
     client: ImagebuilderClient = boto3.client("imagebuilder")
     session_client: ImagebuilderClient = session.client("imagebuilder")
 """
-from mypy_boto3_imagebuilder.client import ImagebuilderClient as Client, ImagebuilderClient
+from mypy_boto3_imagebuilder.client import ImagebuilderClient, ImagebuilderClient as Client
 
 
 __all__ = ("Client", "ImagebuilderClient")
